==> pyconnectwise-0.4.5.tar.gz: pyconnectwise-0.4.5/src/pyconnectwise/endpoints/manage/FinanceCurrenciesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.FinanceCurrenciesCountEndpoint import FinanceCurrenciesCountEndpoint
from pyconnectwise.endpoints.manage.FinanceCurrenciesIdEndpoint import FinanceCurrenciesIdEndpoint
from pyconnectwise.endpoints.manage.FinanceCurrenciesInfoEndpoint import FinanceCurrenciesInfoEndpoint
from pyconnectwise.models.manage import FinanceCurrency
from pyconnectwise.responses.paginated_response import PaginatedResponse


class FinanceCurrenciesEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "currencies", parent_endpoint=parent_endpoint)

        self.info = self._register_child_endpoint(FinanceCurrenciesInfoEndpoint(client, parent_endpoint=self))
        self.count = self._register_child_endpoint(FinanceCurrenciesCountEndpoint(client, parent_endpoint=self))

    def id(self, id: int) -> FinanceCurrenciesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized FinanceCurrenciesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            FinanceCurrenciesIdEndpoint: The initialized FinanceCurrenciesIdEndpoint object.
        """
        child = FinanceCurrenciesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[FinanceCurrency]:
        """
        Performs a GET request against the /finance/currencies endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[FinanceCurrency]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            FinanceCurrency,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[FinanceCurrency]:
        """
        Performs a GET request against the /finance/currencies endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[FinanceCurrency]: The parsed response data.
        """
        return self._parse_many(FinanceCurrency, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> FinanceCurrency:
        """
        Performs a POST request against the /finance/currencies endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            FinanceCurrency: The parsed response data.
        """
        return self._parse_one(FinanceCurrency, super()._make_request("POST", data=data, params=params).json())

==> pyconnectwise-0.4.7.tar.gz: pyconnectwise-0.4.7/src/pyconnectwise/endpoints/manage/FinanceCurrenciesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.FinanceCurrenciesCountEndpoint import FinanceCurrenciesCountEndpoint
from pyconnectwise.endpoints.manage.FinanceCurrenciesIdEndpoint import FinanceCurrenciesIdEndpoint
from pyconnectwise.endpoints.manage.FinanceCurrenciesInfoEndpoint import FinanceCurrenciesInfoEndpoint
from pyconnectwise.models.manage import FinanceCurrency
from pyconnectwise.responses.paginated_response import PaginatedResponse


class FinanceCurrenciesEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "currencies", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(FinanceCurrenciesCountEndpoint(client, parent_endpoint=self))
        self.info = self._register_child_endpoint(FinanceCurrenciesInfoEndpoint(client, parent_endpoint=self))

    def id(self, id: int) -> FinanceCurrenciesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized FinanceCurrenciesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            FinanceCurrenciesIdEndpoint: The initialized FinanceCurrenciesIdEndpoint object.
        """
        child = FinanceCurrenciesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[FinanceCurrency]:
        """
        Performs a GET request against the /finance/currencies endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[FinanceCurrency]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params), FinanceCurrency, self, page, page_size, params
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[FinanceCurrency]:
        """
        Performs a GET request against the /finance/currencies endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[FinanceCurrency]: The parsed response data.
        """
        return self._parse_many(FinanceCurrency, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> FinanceCurrency:
        """
        Performs a POST request against the /finance/currencies endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            FinanceCurrency: The parsed response data.
        """
        return self._parse_one(FinanceCurrency, super()._make_request("POST", data=data, params=params).json())
